setActiveBuffer static method
Sets the active buffer and prompt label for raw mode.
Implementation
static void setActiveBuffer(StringBuffer buffer, String promptLabel) {
_activeBuffer = buffer;
_activePromptLabel = promptLabel;
}
Sets the active buffer and prompt label for raw mode.
static void setActiveBuffer(StringBuffer buffer, String promptLabel) {
_activeBuffer = buffer;
_activePromptLabel = promptLabel;
}