init method
The init method is used to initialize the controller.
Implementation
void init({required CappManager manager}) {
this.manager = manager;
}
The init method is used to initialize the controller.
void init({required CappManager manager}) {
this.manager = manager;
}