chainFlag constant
String
const chainFlag
The flag used to chain multiple commands in a single input (e.g. test -p --and help).
Implementation
static const chainFlag = '--and';
The flag used to chain multiple commands in a single input (e.g. test -p --and help).
static const chainFlag = '--and';