hideInHelp property
hideInHelp is a boolean value that represents if the option should be hidden in the help command or not.
Implementation
bool hideInHelp;
hideInHelp is a boolean value that represents if the option should be hidden in the help command or not.
bool hideInHelp;