resetValue method
void
resetValue()
The resetValue method is used to reset the value of the option to the default value.
Implementation
void resetValue() {
value = _defaultValue;
existsInArgs = false;
}
The resetValue method is used to reset the value of the option to the default value.
void resetValue() {
value = _defaultValue;
existsInArgs = false;
}