console library
Classes
- Console
-
A utility class for logging messages with different severity levels.
The Console class provides static methods for logging warnings, errors,
information, debugging messages, and fatal errors. The logs are managed using
the
Loggerpackage and optionally printed to the console. Example usage: - LanguageToDart
- WidgetToDart
Typedefs
- LogCallback = void Function(Object? log, String type)