isNotDebug property
bool
get
isNotDebug
Checks if the application is not running in debug mode.
Implementation
static bool get isNotDebug => !isDebug;
Checks if the application is not running in debug mode.
static bool get isNotDebug => !isDebug;