LanguageToDart class

Constructors

LanguageToDart(String path, {String fileExtention = '.json'})

Properties

fileExtention String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
path String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() Future<({Map<String, Map<String, String>> map, String path})>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited