onCron property

Future Function(int count, FinchCron cron) onCron
getter/setter pair

The callback function to be executed on each cron tick.

The function receives the current tick count and the FinchCron instance as parameters.

Implementation

Future Function(int count, FinchCron cron) onCron;