menu
finch package
documentation
finch_capp.dart
finch_capp.dart
dark_mode
light_mode
finch_capp
library
Classes
CappConsole
CappConsole
is a class that helps you to interact with the console. Here are some Console widgets that you can use
CappController
CappController
is a class that represents a controller in the console application. The controller is a class that contains the main logic of the application. The controller can have options that can be passed to the controller from the console.
CappManager
CappManager
is a class that represents the manager of the console application. The manager is a class that contains the main logic of the application.
CappOption
CappOption class is a class that represents an option in the console application.
Key
Enums
CappColors
CappColors
is an enum that contains the colors that can be used in the console. The colors are none, warning, error, success, info, and off.
CappProgressType
CappProgressType
is an enum that contains three types of progress widgets. The types are spinner, bar, timer, and circle.
ControlCharacter
finch package
documentation
finch_capp.dart
finch
package
Libraries
app
capp
console
finch_app
finch_capp
finch_console
finch_htmler
finch_json
finch_mail
finch_model
finch_model_less
finch_mongo_db
finch_mysql
finch_route
finch_sqlite
finch_sqlite_client
finch_tools
finch_ui
htmler
json
mail
model
model_less
mongo_db
mysql
route
sqlite
sqlite_client
tools
ui
finch_capp library