CacheParam enum

Parameters used to generate a unique cache key for requests.

Inheritance
Available extensions

Values

path → const CacheParam

Includes the request path in the cache key.

method → const CacheParam

Includes the request HTTP method in the cache key.

query → const CacheParam

Includes the request query string in the cache key.

data → const CacheParam

Includes the request body data in the cache key.

language → const CacheParam

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CacheParam>
A constant List of the values in this enum, in order of their declaration.