Middleware class abstract

Constructors

Middleware()

Properties

hashCode → int
The hash code for this object.
no setterinherited
rq → Request
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited