TagType enum

Enumeration defining the types of HTML tags. This enum distinguishes between different HTML tag structures:

  • single: Self-closing tags that don't have content (e.g., <br/>, <img/>)
  • double: Container tags with opening and closing parts (e.g., <div></div>, <p></p>)
Inheritance
Available extensions

Values

single → const TagType

Self-closing HTML tags like <br/>, <img/>, <input/>

double → const TagType

Container HTML tags with opening and closing parts like <div></div>, <span></span>

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagType>
A constant List of the values in this enum, in order of their declaration.