BlobResourceContents class

Binary resource content encoded as base64.

Inheritance

Constructors

BlobResourceContents({required String blob, required String uri, String? mimeType, MetaObject? $meta})
BlobResourceContents.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
Optional metadata.
getter/setter pairinherited
blob String
Base64-encoded binary content.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
Optional MIME type of the resource.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
The resource URI.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited