BooleanSchema class

The MCP BooleanSchema schema type.

Inheritance

Constructors

BooleanSchema({String? title, String? description, bool? defaultValue})
Creates a BooleanSchema.
BooleanSchema.toMCP(Map<String, Object?> map)
Builds a BooleanSchema from a decoded MCP JSON map.
factory

Properties

defaultValue bool?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this Schema into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited