CacheScope enum

Cache scope for a cacheable result (see DiscoverResult and the various List*Result / ReadResourceResult types).

Inheritance
Available extensions

Values

public → const CacheScope
const CacheScope('public')
private → const CacheScope
const CacheScope('private')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CacheScope>
A constant List of the values in this enum, in order of their declaration.