CallToolRequest class
A tools/call JSON-RPC request.
Constructors
- CallToolRequest({required String id, required CallToolRequestParams params})
-
CallToolRequest.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- jsonrpc ↔ String
-
getter/setter pair
- method ↔ String
-
getter/setter pair
- params ↔ CallToolRequestParams
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited