CancelledNotificationParams class

Parameters for a notifications/cancelled notification.

Inheritance

Constructors

CancelledNotificationParams({NotificationMetaObject? $meta, required String requestId, String? reason})
Creates a CancelledNotificationParams.
CancelledNotificationParams.toMCP(Map<String, Object?> map)
Builds a CancelledNotificationParams from a decoded MCP JSON map.
factory

Properties

$meta NotificationMetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reason String?
An optional string describing the reason for the cancellation.
getter/setter pair
requestId String
The ID of the request to cancel.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CancelledNotificationParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited