ClientCapabilities class

Capabilities declared by the MCP client.

Known keys: experimental, elicitation ({form?, url?}), extensions.

roots and sampling remain valid keys but are deprecated as of protocol version 2026-07-28 (SEP-2577); they remain in the specification for at least twelve months. See the deprecated features registry.

Inheritance
Implemented types
Available extensions

Constructors

ClientCapabilities(Map<String, Object?> data)
Creates a ClientCapabilities.
ClientCapabilities.toMCP(Map<String, Object?> map)
Builds a ClientCapabilities from a decoded MCP JSON map.
factory

Properties

data Map<String, Object?>
The underlying map data.
finalinherited
entries Iterable<MapEntry<String, Object?>>
See Map.entries.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
See Map.isEmpty.
no setterinherited
isNotEmpty bool
See Map.isNotEmpty.
no setterinherited
keys Iterable<String>
See Map.keys.
no setterinherited
length int
See Map.length.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<Object?>
See Map.values.
no setterinherited

Methods

addAll(Map<String, Object?> other) → void
See Map.addAll.
inherited
addEntries(Iterable<MapEntry<String, Object?>> newEntries) → void
See Map.addEntries.
inherited
cast<RK, RV>() Map<RK, RV>
See Map.cast.
inherited
clear() → void
See Map.clear.
inherited
containsKey(Object? key) bool
See Map.containsKey.
inherited
containsValue(Object? value) bool
See Map.containsValue.
inherited
forEach(void action(String key, Object? value)) → void
See Map.forEach.
inherited
map<K2, V2>(MapEntry<K2, V2> convert(String key, Object? value)) Map<K2, V2>
See Map.map.
inherited

Available on Map<String, dynamic>, provided by the MapPath extension

Navigates through the map using the provided path and retrieves a value of type T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, Object? ifAbsent()) Object?
See Map.putIfAbsent.
inherited
remove(Object? key) Object?
See Map.remove.
inherited
removeWhere(bool test(String key, Object? value)) → void
See Map.removeWhere.
inherited
toMap() Map<String, Object?>
Converts this ClientCapabilities into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited
update(String key, Object? update(Object? key), {Object? ifAbsent()?}) Object?
See Map.update.
inherited
updateAll(Object? update(String key, Object? value)) → void
See Map.updateAll.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
Delegates to the underlying map's [] operator.
inherited
operator []=(String key, Object? value) → void
Delegates to the underlying map's []= operator.
inherited