CompleteRequestParams class

Parameters for a completion/complete request.

Inheritance

Constructors

CompleteRequestParams({required RequestMetaObject $meta, required Reference ref, required CompleteRequestParamsArgument argument, CompleteRequestParamsContext? context})
Creates a CompleteRequestParams.
CompleteRequestParams.toMCP(Map<String, Object?> map)
Builds a CompleteRequestParams from a decoded MCP JSON map.
factory

Properties

$meta RequestMetaObject
getter/setter pair
argument CompleteRequestParamsArgument
The argument's information
getter/setter pair
context CompleteRequestParamsContext?
Additional, optional context for completions
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ref Reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CompleteRequestParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited