CompleteRequestParamsArgument class

The MCP CompleteRequestParamsArgument schema type.

Inheritance

Constructors

CompleteRequestParamsArgument({required String name, required String value})
Creates a CompleteRequestParamsArgument.
CompleteRequestParamsArgument.toMCP(Map<String, Object?> map)
Builds a CompleteRequestParamsArgument from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CompleteRequestParamsArgument into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited