CompleteRequestParamsContext class

The MCP CompleteRequestParamsContext schema type.

Inheritance

Constructors

CompleteRequestParamsContext({Map<String, String>? arguments})
Creates a CompleteRequestParamsContext.
CompleteRequestParamsContext.toMCP(Map<String, Object?> map)
Builds a CompleteRequestParamsContext from a decoded MCP JSON map.
factory

Properties

arguments Map<String, String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CompleteRequestParamsContext into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited