CompleteResult class

The result returned by the server for a completion/complete request.

Inheritance
Implemented types
Available extensions

Constructors

CompleteResult({ResultMetaObject? $meta, String resultType = 'complete', required CompleteResultCompletion completion, Map<String, Object?>? additionalData})
Creates a CompleteResult.
CompleteResult.toMCP(Map<String, Object?> map)
Builds a CompleteResult from a decoded MCP JSON map.
factory

Properties

$meta ResultMetaObject?
getter/setter pair
completion CompleteResultCompletion
An array of completion values.
getter/setter pair
data Map<String, Object?>
The underlying map data.
finalinherited
entries Iterable<MapEntry<String, Object?>>
See Map.entries.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
See Map.isEmpty.
no setterinherited
isNotEmpty bool
See Map.isNotEmpty.
no setterinherited
keys Iterable<String>
See Map.keys.
no setterinherited
length int
See Map.length.
no setterinherited
resultType String
Indicates the type of the result, which allows the client to determine how to parse the result object.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<Object?>
See Map.values.
no setterinherited

Methods

addAll(Map<String, Object?> other) → void
See Map.addAll.
inherited
addEntries(Iterable<MapEntry<String, Object?>> newEntries) → void
See Map.addEntries.
inherited
cast<RK, RV>() Map<RK, RV>
See Map.cast.
inherited
clear() → void
See Map.clear.
inherited
containsKey(Object? key) bool
See Map.containsKey.
inherited
containsValue(Object? value) bool
See Map.containsValue.
inherited
forEach(void action(String key, Object? value)) → void
See Map.forEach.
inherited
map<K2, V2>(MapEntry<K2, V2> convert(String key, Object? value)) Map<K2, V2>
See Map.map.
inherited

Available on Map<String, dynamic>, provided by the MapPath extension

Navigates through the map using the provided path and retrieves a value of type T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, Object? ifAbsent()) Object?
See Map.putIfAbsent.
inherited
remove(Object? key) Object?
See Map.remove.
inherited
removeWhere(bool test(String key, Object? value)) → void
See Map.removeWhere.
inherited
toMap() Map<String, Object?>
Converts this CompleteResult into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited
update(String key, Object? update(Object? key), {Object? ifAbsent()?}) Object?
See Map.update.
inherited
updateAll(Object? update(String key, Object? value)) → void
See Map.updateAll.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
Delegates to the underlying map's [] operator.
inherited
operator []=(String key, Object? value) → void
Delegates to the underlying map's []= operator.
inherited