resultType property
Indicates the type of the result, which allows the client to determine how to parse the result object.
Implementation
String resultType;
Indicates the type of the result, which allows the client to determine how to parse the result object.
String resultType;