CompleteResultCompletion class

The MCP CompleteResultCompletion schema type.

Inheritance

Constructors

CompleteResultCompletion({required List<String> values, int? total, bool? hasMore})
Creates a CompleteResultCompletion.
CompleteResultCompletion.toMCP(Map<String, Object?> map)
Builds a CompleteResultCompletion from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int?
getter/setter pair
values List<String>
Completion values. Must not exceed 100 items.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CompleteResultCompletion into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited