includeContext property
A request to include context from one or more MCP servers (including the caller), to be attached to the prompt.
Implementation
String? includeContext;
A request to include context from one or more MCP servers (including the caller), to be attached to the prompt.
String? includeContext;