CreateMessageResult class

The result returned by the client for a sampling/createMessage request.

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

CreateMessageResult({required String model, String? stopReason, required Role role, required List<ContentBlock> content, MetaObject? $meta})
Creates a CreateMessageResult.
CreateMessageResult.toMCP(Map<String, Object?> map)
Builds a CreateMessageResult from a decoded MCP JSON map.
factory

Properties

$meta MetaObject?
getter/setter pair
content List<ContentBlock>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
model String
The name of the model that generated the message.
getter/setter pair
role Role
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopReason String?
The reason why sampling stopped, if known.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this CreateMessageResult into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited