DiscoverResultResponse class

A successful response from the server for a server/discover request.

Inheritance

Constructors

DiscoverResultResponse({required String id, required DiscoverResult result})
Creates a DiscoverResultResponse.
DiscoverResultResponse.toMCP(Map<String, Object?> map)
Builds a DiscoverResultResponse from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
jsonrpc String
getter/setter pair
result DiscoverResult
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this DiscoverResultResponse into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited