ElicitRequestFormParamsSchema class

Inheritance

Constructors

ElicitRequestFormParamsSchema({String? $schema, List<String>? required, String type = 'object', required Map<String, PrimitiveSchemaDefinition> properties})
ElicitRequestFormParamsSchema.toMCP(Map<String, Object?> map)
factory

Properties

$schema String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
properties Map<String, PrimitiveSchemaDefinition>
getter/setter pair
required List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited