ElicitResult class
The result returned by the client for an elicitation/create request.
Constructors
-
ElicitResult({MetaObject? $meta, required ActionType action, required Map<
String, Object?> content}) - Creates an ElicitResult.
-
ElicitResult.toMCP(Map<
String, Object?> map) -
Builds an ElicitResult from a decoded MCP JSON map.
factory
Properties
- $meta ↔ MetaObject?
-
getter/setter pair
- action ↔ ActionType
-
The user action in response to the elicitation.
getter/setter pair
-
content
↔ Map<
String, Object?> -
The submitted form data, only present when action is "accept" and mode was "form".
getter/setter pair
-
data
→ Map<
String, Object?> -
The underlying map data.
finalinherited
-
entries
→ Iterable<
MapEntry< String, Object?> > -
See Map.entries.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
See Map.isEmpty.
no setterinherited
- isNotEmpty → bool
-
See Map.isNotEmpty.
no setterinherited
-
keys
→ Iterable<
String> -
See Map.keys.
no setterinherited
- length → int
-
See Map.length.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Iterable<
Object?> -
See Map.values.
no setterinherited
Methods
-
addAll(
Map< String, Object?> other) → void -
See Map.addAll.
inherited
-
addEntries(
Iterable< MapEntry< newEntries) → voidString, Object?> > -
See Map.addEntries.
inherited
-
cast<
RK, RV> () → Map< RK, RV> -
See Map.cast.
inherited
-
clear(
) → void -
See Map.clear.
inherited
-
containsKey(
Object? key) → bool -
See Map.containsKey.
inherited
-
containsValue(
Object? value) → bool -
See Map.containsValue.
inherited
-
forEach(
void action(String key, Object? value)) → void -
See Map.forEach.
inherited
-
map<
K2, V2> (MapEntry< K2, V2> convert(String key, Object? value)) → Map<K2, V2> -
See Map.map.
inherited
-
Available on Map<
Navigates through the map using the provided path and retrieves a value of typeString, dynamic> , provided by the MapPath extensionT. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, Object? ifAbsent()) → Object? -
See Map.putIfAbsent.
inherited
-
remove(
Object? key) → Object? -
See Map.remove.
inherited
-
removeWhere(
bool test(String key, Object? value)) → void -
See Map.removeWhere.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this ElicitResult into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String key, Object? update(Object? key), {Object? ifAbsent()?}) → Object? -
See Map.update.
inherited
-
updateAll(
Object? update(String key, Object? value)) → void -
See Map.updateAll.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → Object? -
Delegates to the underlying map's
[]operator.inherited -
operator []=(
String key, Object? value) → void -
Delegates to the underlying map's
[]=operator.inherited