EmptyResult class
A successful result that carries no data.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta ↔ MetaObject?
-
Optional
_metaobject.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unknown
↔ Map<
String, Object?> ? -
Any additional unknown fields returned by the server.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited