Error class

A JSON-RPC 2.0 error object.

Inheritance

Constructors

Error({required int code, required String message, Object? data})
Error.toMCP(Map<String, Object?> map)
factory

Properties

code int
Machine-readable error code (e.g. -32600 for invalid request).
getter/setter pair
data Object?
Optional additional error data (provider-defined).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
Short, human-readable error description.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited