GetPromptRequestParams class

Inheritance

Constructors

GetPromptRequestParams({RequestMetaObject? $meta, dynamic inputResponses, String? requestState, required String name, Map<String, String>? arguments})
GetPromptRequestParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta RequestMetaObject?
getter/setter pair
arguments Map<String, String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputResponses ↔ dynamic
getter/setter pair
name String
getter/setter pair
requestState String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited