InitializeRequest class

The MCP initialize request sent by the client on first connect.

Inheritance

Constructors

InitializeRequest({required String id, required InitializeRequestParams params})
InitializeRequest.toMCP(Map<String, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Request id.
getter/setter pair
jsonrpc String
JSON-RPC version string.
getter/setter pair
method String
Fixed method name.
getter/setter pair
params InitializeRequestParams
Initialization parameters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited