InitializeRequestParams class

Parameters for an initialize request.

Inheritance

Constructors

InitializeRequestParams({RequestMetaObject? $meta, required String protocolVersion, required ClientCapabilities capabilities, required Implementation clientInfo})
InitializeRequestParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta RequestMetaObject?
Optional request metadata.
getter/setter pair
capabilities ClientCapabilities
Client-declared capabilities.
getter/setter pair
clientInfo Implementation
Information about this client implementation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
protocolVersion String
Highest MCP protocol version the client supports.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited