JSONRPCErrorResponse class
A JSON-RPC 2.0 error response.
Sent in reply to a request when an error occurred on the receiver's side.
- Inheritance
-
- Object
- MCP
- JSONRPCMessage
- JSONRPCErrorResponse
Constructors
- JSONRPCErrorResponse({String jsonrpc = '2.0', String? id, required Error error})
-
JSONRPCErrorResponse.toMCP(Map<
String, Object?> map) -
factory
Properties
- error ↔ Error
-
The structured error payload.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The id of the originating request, if available.
getter/setter pair
- jsonrpc ↔ String
-
JSON-RPC version string, always
"2.0".getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited