JSONRPCRequest class
A JSON-RPC 2.0 request that expects a response.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
Unique request identifier.
getter/setter pair
- jsonrpc ↔ String
-
JSON-RPC version string.
getter/setter pair
- method ↔ String
-
The request method name.
getter/setter pair
-
params
↔ Map<
String, Object?> ? -
Optional request parameters.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited