JSONRPCResultResponse class
A successful JSON-RPC 2.0 response carrying a Result.
- Inheritance
-
- Object
- MCP
- JSONRPCMessage
- JSONRPCResponse
- JSONRPCResultResponse
Constructors
- JSONRPCResultResponse({String jsonrpc = '2.0', String? id, required Result result})
-
JSONRPCResultResponse.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The id of the originating request.
getter/setter pair
- jsonrpc ↔ String
-
JSON-RPC version string.
getter/setter pair
- result ↔ Result
-
The result payload.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited