LegacyTitledEnumSchema class

Use TitledSingleSelectEnumSchema instead.

Inheritance
Annotations
  • @Deprecated('Use TitledSingleSelectEnumSchema instead.')

Constructors

LegacyTitledEnumSchema({required List<String> $enum, List<String>? enumNames, String? defaultValue, String? title, String? description})
Creates a LegacyTitledEnumSchema.
LegacyTitledEnumSchema.toMCP(Map<String, Object?> map)
Builds a LegacyTitledEnumSchema from a decoded MCP JSON map.
factory

Properties

$enum List<String>
getter/setter pair
defaultValue String?
getter/setter pairinherited
description String?
getter/setter pairinherited
enumNames List<String>?
(Legacy) Display names for enum values.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this LegacyTitledEnumSchema into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited