resultType property

String get resultType

Indicates the type of the result, which allows the client to determine how to parse the result object.

Implementation

String get resultType => data['resultType'] as String? ?? 'complete';
set resultType (String value)

Implementation

set resultType(String value) => data['resultType'] = value;