ListResourceTemplatesResultResponse class

Inheritance
  • Object
  • MCP
  • ListResourceTemplatesResultResponse

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
jsonrpc String
getter/setter pair
result ListResourceTemplatesResult
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited