LoggingLevel enum

The severity of a log message, mapped to syslog severities (RFC-5424).

Inheritance
Available extensions
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Values

debug → const LoggingLevel

Detailed information useful for debugging.

const LoggingLevel('debug')
info → const LoggingLevel

Normal operational messages.

const LoggingLevel('info')
notice → const LoggingLevel

Normal but significant events.

const LoggingLevel('notice')
warning → const LoggingLevel

Warning conditions.

const LoggingLevel('warning')
error → const LoggingLevel

Error conditions.

const LoggingLevel('error')
critical → const LoggingLevel

Critical conditions.

const LoggingLevel('critical')
alert → const LoggingLevel

Action must be taken immediately.

const LoggingLevel('alert')
emergency → const LoggingLevel

The system is unusable.

const LoggingLevel('emergency')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The wire value sent over JSON-RPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LoggingLevel>
A constant List of the values in this enum, in order of their declaration.