LoggingMessageNotification class

JSONRPCNotification of a log message passed from server to client.

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

LoggingMessageNotification({required LoggingMessageNotificationParams params})
Creates a LoggingMessageNotification.
LoggingMessageNotification.toMCP(Map<String, Object?> map)
Builds a LoggingMessageNotification from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonrpc String
getter/setter pair
method String
getter/setter pair
params LoggingMessageNotificationParams
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this LoggingMessageNotification into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited