McpProtocolVersion enum

Inheritance
Available extensions

Values

v2025_11_25 → const McpProtocolVersion
const McpProtocolVersion(version: '2025-11-25')
v2026_07_28 → const McpProtocolVersion
const McpProtocolVersion(version: '2026-07-28')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<McpProtocolVersion>
A constant List of the values in this enum, in order of their declaration.