MetaObject class

Holds the _meta map present on many MCP types.

Inheritance

Constructors

MetaObject(Map<String, Object?> _data)
MetaObject.toMCP(Map<String, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited