ModelHint class

Hints to use for model selection.

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

ModelHint({String? name})
Creates a ModelHint.
ModelHint.toMCP(Map<String, Object?> map)
Builds a ModelHint from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
A hint for a model name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ModelHint into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited