ModelPreferences class

The server's preferences for model selection, requested of the client during sampling.

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

ModelPreferences({List<ModelHint>? hints, num? costPriority, num? speedPriority, num? intelligencePriority})
Creates a ModelPreferences.
ModelPreferences.toMCP(Map<String, Object?> map)
Builds a ModelPreferences from a decoded MCP JSON map.
factory

Properties

costPriority num?
How much to prioritize cost when selecting a model.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hints List<ModelHint>?
Optional hints to use for model selection.
getter/setter pair
intelligencePriority num?
How much to prioritize intelligence and capabilities when selecting a model.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedPriority num?
How much to prioritize sampling speed (latency) when selecting a model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ModelPreferences into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited