NotificationParams class

Parameters shared by MCP notifications.

Inheritance

Constructors

NotificationParams({NotificationMetaObject? $meta})
Creates a NotificationParams.
NotificationParams.toMCP(Map<String, Object?> map)
Builds a NotificationParams from a decoded MCP JSON map.
factory

Properties

$meta NotificationMetaObject?
Optional notification metadata.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this NotificationParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited