NumberSchema class
The MCP NumberSchema schema type.
Constructors
- NumberSchema({String type = 'number', num? minimum, num? maximum, num? defaultValue, String? title, String? description})
- Creates a NumberSchema.
-
NumberSchema.toMCP(Map<
String, Object?> map) -
Builds a NumberSchema from a decoded MCP JSON map.
factory
Properties
- defaultValue ↔ num?
-
getter/setter pairinherited
- description ↔ String?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximum ↔ num?
-
getter/setter pair
- minimum ↔ num?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
getter/setter pairinherited
- type ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this NumberSchema into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited