PaginatedRequestParams class
Request params for paginated MCP list calls.
Constructors
- PaginatedRequestParams({String? cursor, RequestMetaObject? $meta})
-
PaginatedRequestParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ RequestMetaObject?
-
Optional request metadata.
getter/setter pair
- cursor ↔ String?
-
Opaque pagination cursor from a previous response.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited