ParseError class
JSON-RPC parse error (code -32700).
Constructors
- ParseError({required String message, Object? data})
Properties
- code ↔ int
-
Machine-readable error code (e.g.
-32600for invalid request).getter/setter pairinherited - data ↔ Object?
-
Optional additional error data (provider-defined).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
Short, human-readable error description.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited