PrimitiveSchemaDefinition<T> class abstract

Restricted schema definitions that only allow primitive types without nested objects or arrays.

Inheritance

Constructors

PrimitiveSchemaDefinition({required String type, String? title, String? description, T? defaultValue})
Creates a PrimitiveSchemaDefinition.

Properties

defaultValue ↔ T?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this Schema into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited