ProgressNotification class

An out-of-band notification used to inform the receiver of a progress update for a long-running request.

Inheritance

Constructors

ProgressNotification({required ProgressNotificationParams params})
Creates a ProgressNotification.
ProgressNotification.toMCP(Map<String, Object?> map)
Builds a ProgressNotification from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonrpc String
getter/setter pair
method String
getter/setter pair
params ProgressNotificationParams
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ProgressNotification into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited