ProgressNotificationParams class

Parameters for a notifications/progress notification.

Inheritance

Constructors

ProgressNotificationParams({NotificationMetaObject? $meta, required String progressToken, required num progress, num? total, String? message})
Creates a ProgressNotificationParams.
ProgressNotificationParams.toMCP(Map<String, Object?> map)
Builds a ProgressNotificationParams from a decoded MCP JSON map.
factory

Properties

$meta NotificationMetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
An optional message describing the current progress.
getter/setter pair
progress num
The progress thus far.
getter/setter pair
progressToken String
The progress token which was given in the initial request, used to associate this notification with the request that is proceeding.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total num?
Total number of items to process (or total progress required), if known.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ProgressNotificationParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited