Prompt class

A prompt or prompt template offered by the server.

Inheritance

Constructors

Prompt({List<Icon>? icons, required String name, String? title, String? description, List<PromptArgument>? arguments, MetaObject? $meta})
Prompt.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
Optional metadata.
getter/setter pair
arguments List<PromptArgument>?
Accepted template arguments.
getter/setter pair
description String?
Optional description.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icons List<Icon>?
Optional display icons.
getter/setter pair
name String
Programmatic name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Human-readable display title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited