PromptReference class

Identifies a prompt.

Inheritance

Constructors

PromptReference({required String name, String? title})
Creates a PromptReference.
PromptReference.toMCP(Map<String, Object?> map)
Builds a PromptReference from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Intended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn't present).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Intended for UI and end-user contexts — optimized to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this PromptReference into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited