Reference class abstract

Discriminated union of completion reference targets: either a PromptReference (type: "ref/prompt") or a ResourceTemplateReference (type: "ref/resource").

Inheritance

Constructors

Reference()
Creates a Reference.
Reference.toMCP(Map<String, Object?> map)
Builds a Reference from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited