logLevel property

  1. @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')
LoggingLevel? get logLevel

The desired log level for this request.

Implementation

@Deprecated(
  'Deprecated as of protocol version 2026-07-28 (SEP-2577). '
  'Remains in the specification for at least twelve months.',
)
LoggingLevel? get logLevel =>
    data['io.modelcontextprotocol/logLevel'] != null
        ? LoggingLevel.to(data['io.modelcontextprotocol/logLevel'] as String)
        : null;
  1. @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')
set logLevel (LoggingLevel? value)

Implementation

@Deprecated(
  'Deprecated as of protocol version 2026-07-28 (SEP-2577). '
  'Remains in the specification for at least twelve months.',
)
set logLevel(LoggingLevel? value) =>
    data['io.modelcontextprotocol/logLevel'] = value?.toString();