ResourceContents class interface
Base interface for resource content (text or blob).
Constructors
- ResourceContents({required String uri, String? mimeType, MetaObject? $meta})
-
ResourceContents.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
Optional metadata.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String?
-
Optional MIME type of the resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri ↔ String
-
The resource URI.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited