ResourceListChangedNotification class

An optional notification from the server to the client, informing it that the list of resources it can read from has changed.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonrpc String
getter/setter pair
method String
getter/setter pair
params NotificationParams?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ResourceListChangedNotification into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited