ResourceTemplate class

A URI template (RFC 6570) describing a family of resources.

Inheritance

Constructors

ResourceTemplate({List<Icon>? icons, required String name, String? title, required String uriTemplate, String? description, String? mimeType, Annotations? annotations, MetaObject? $meta})
ResourceTemplate.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
Optional metadata.
getter/setter pair
annotations Annotations?
Optional client annotations.
getter/setter pair
description String?
Human-readable description of the template.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icons List<Icon>?
Optional display icons.
getter/setter pair
mimeType String?
Shared MIME type for all resources matching this template.
getter/setter pair
name String
Programmatic name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Human-readable display title.
getter/setter pair
uriTemplate String
RFC 6570 URI template.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited