ResourceTemplateReference class
A reference to a resource or resource template definition.
Constructors
- ResourceTemplateReference({required String uri})
- Creates a ResourceTemplateReference.
-
ResourceTemplateReference.toMCP(Map<
String, Object?> map) -
Builds a ResourceTemplateReference from a decoded MCP JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
Discriminator. Note this is
"ref/resource", shared with plain resource references — not"ref/resource_template".getter/setter pair - uri ↔ String
-
The URI or URI template of the resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this ResourceTemplateReference into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited