ResourceUpdatedNotificationParams class
Parameters for a notifications/resources/updated notification.
Constructors
- ResourceUpdatedNotificationParams({NotificationMetaObject? $meta, required String uri})
- Creates a ResourceUpdatedNotificationParams.
-
ResourceUpdatedNotificationParams.toMCP(Map<
String, Object?> map) -
Builds a ResourceUpdatedNotificationParams from a decoded MCP JSON map.
factory
Properties
- $meta ↔ NotificationMetaObject?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri ↔ String
-
The URI of the resource that has been updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this ResourceUpdatedNotificationParams into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited