ResultType enum

Indicates the type of a result, so a client knows how to parse it.

Inheritance
Available extensions

Values

complete → const ResultType

The result is complete and contains the final payload.

const ResultType('complete')
inputRequired → const ResultType

The result indicates further input is required before completion.

const ResultType('input_required')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The wire value sent over JSON-RPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

to(String str) ResultType
Looks up the ResultType whose wire value equals str.

Constants

values → const List<ResultType>
A constant List of the values in this enum, in order of their declaration.