Root class

Represents a root directory or file that the server can operate on.

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

Root({required String uri, String? name, MetaObject? $meta})
Creates a Root.
Root.toMCP(Map<String, Object?> map)
Builds a Root from a decoded MCP JSON map.
factory

Properties

$meta MetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
An optional name for the root.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
The URI identifying the root.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this Root into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited