Schema<T> class

The MCP Schema schema type.

Inheritance

Constructors

Schema({required String type, String? title, String? description, T? defaultValue})
Creates a Schema.
Schema.toMCP(Map<String, Object?> map)
Builds a Schema from a decoded MCP JSON map.
factory

Properties

defaultValue ↔ T?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this Schema into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited