SingleSelectEnumSchema<T> class abstract

Inheritance

Constructors

SingleSelectEnumSchema({required String type, String? title, String? description, T? defaultValue})

Properties

defaultValue ↔ T?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited