StringSchema class

The MCP StringSchema schema type.

Inheritance

Constructors

StringSchema({int? minLength, int? maxLength, StringFormat? format, String? defaultValue, String? title, String? description})
Creates a StringSchema.
StringSchema.toMCP(Map<String, Object?> map)
Builds a StringSchema from a decoded MCP JSON map.
factory

Properties

defaultValue String?
getter/setter pairinherited
description String?
getter/setter pairinherited
format StringFormat?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxLength int?
getter/setter pair
minLength int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this StringSchema into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited