SubscriptionFilter class

Filter describing which change notifications a subscriptions/listen stream should deliver.

Inheritance

Constructors

SubscriptionFilter({bool? toolsListChanged, bool? promptsListChanged, bool? resourcesListChanged, List<String>? resourceSubscriptions})
Creates a SubscriptionFilter.
SubscriptionFilter.toMCP(Map<String, Object?> map)
Builds a SubscriptionFilter from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
promptsListChanged bool?
If true, receive notifications/prompts/list_changed.
getter/setter pair
resourcesListChanged bool?
If true, receive notifications/resources/list_changed.
getter/setter pair
resourceSubscriptions List<String>?
Subscribe to notifications/resources/updated for these resource URIs.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsListChanged bool?
If true, receive notifications/tools/list_changed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this SubscriptionFilter into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited