SubscriptionsListenRequestParams class
Parameters for a subscriptions/listen request.
Constructors
- SubscriptionsListenRequestParams({required RequestMetaObject $meta, required SubscriptionFilter notifications})
- Creates a SubscriptionsListenRequestParams.
-
SubscriptionsListenRequestParams.toMCP(Map<
String, Object?> map) -
Builds a SubscriptionsListenRequestParams from a decoded MCP JSON map.
factory
Properties
- $meta ↔ RequestMetaObject
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifications ↔ SubscriptionFilter
-
The notifications the client opts in to on this stream.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this SubscriptionsListenRequestParams into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited