TaskStatus enum

The status of an MCP task.

Inheritance
Available extensions

Values

working → const TaskStatus
const TaskStatus('working')
completed → const TaskStatus
const TaskStatus('completed')
failed → const TaskStatus
const TaskStatus('failed')
cancelled → const TaskStatus
const TaskStatus('cancelled')
inputRequired → const TaskStatus
const TaskStatus('input_required')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

to(String str) TaskStatus

Constants

values → const List<TaskStatus>
A constant List of the values in this enum, in order of their declaration.