TitledSingleSelectEnumSchema class

Inheritance

Constructors

TitledSingleSelectEnumSchema({required List<({String $const, String title})> oneOf, String? defaultValue, String? title, String? description})
TitledSingleSelectEnumSchema.toMCP(Map<String, Object?> map)
factory

Properties

defaultValue String?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
oneOf List<({String $const, String title})>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited