ToolExecution class
Execution-related properties for a Tool.
Constructors
- ToolExecution({String? taskSupport})
-
ToolExecution.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskSupport ↔ String?
-
Whether this tool supports task-augmented execution.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited