UnsupportedProtocolVersionError class
Returned when a server does not support the protocol version requested
via RequestMetaObject["io.modelcontextprotocol/protocolVersion"].
Constructors
-
UnsupportedProtocolVersionError({required String message, required List<
String> supported, required String requested})
Properties
- code ↔ int
-
Machine-readable error code (e.g.
-32600for invalid request).getter/setter pairinherited - data ↔ Object?
-
Optional additional error data (provider-defined).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
Short, human-readable error description.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited