UntitledMultiSelectEnumSchema class

Schema for multiple-selection enumeration without display titles for options.

Inheritance

Constructors

UntitledMultiSelectEnumSchema({required List<String> items, int? minItems, int? maxItems, List<String>? defaultValue, String? title, String? description})
Creates an UntitledMultiSelectEnumSchema.
UntitledMultiSelectEnumSchema.toMCP(Map<String, Object?> map)
Builds an UntitledMultiSelectEnumSchema from a decoded MCP JSON map.
factory

Properties

defaultValue List<String>?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
items List<String>
Schema for the array items.
getter/setter pair
maxItems int?
Maximum number of items to select.
getter/setter pair
minItems int?
Minimum number of items to select.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this UntitledMultiSelectEnumSchema into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited