ApiResponse<T> class

Represents a field in the body of an API request. T - The Dart type of the body field.

Constructors

ApiResponse(String name, {Object? def, String? description})
Creates an instance of ApiBodyField.

Properties

def ↔ Object?
Default value for the body field.
getter/setter pair
description ↔ String?
Optional description of the body field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
The name of the body field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The Dart type of the body field.
no setter
typeString → String
Indicates whether the body field is required.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited