handle property
Pointer<void>
get
handle
The native database connection handle from sqlite.
This returns a pointer towards the opaque sqlite3 structure as defined here.
Note that the connection is still owned by this Dart object, and will be closed once it becomes unreachable. In other words, the returned handle is a logical reference to this object. To transfer ownership of the connection out of this object, use leak instead.
Implementation
Pointer<void> get handle;