statementFromPointer abstract method

PreparedStatement statementFromPointer({
  1. required Pointer<void> statement,
  2. required String sql,
  3. bool borrowed = false,
})

Creates a Dart PreparedStatement instance from the underlying sqlite3_stmt pointer.

When borrowed is set (it defaults to false), the returned Database connection acts as a view of the underlying sqlite3_stmt* pointer. The library will not attach a native finalizer calling sqlite3_finalize, and calling PreparedStatement.close in it will only prevent further interactions from Dart.

Implementation

PreparedStatement statementFromPointer({
  required Pointer<void> statement,
  required String sql,
  bool borrowed = false,
});