handle property

Pointer<void> get handle

The underlying sqlite3_stmt pointer.

Obtains the raw statement from the sqlite3 C-api that this PreparedStatement wraps.

Note that the statement is still owned by this Dart object, and will be finalized once it becomes unreachable. In other words, the returned handle is a logical reference to this object. To transfer ownership of the statement out of this object, use leak instead.

Implementation

Pointer<void> get handle;