columnBlob method
Calls sqlite3_column_blob with the given index.
Note that this performs no bounds check against columnCount in Dart.
Implementation
Uint8List columnBlob(int index) {
return rawStatement.sqlite3_column_bytes(index);
}
Calls sqlite3_column_blob with the given index.
Note that this performs no bounds check against columnCount in Dart.
Uint8List columnBlob(int index) {
return rawStatement.sqlite3_column_bytes(index);
}