columnType method
Calls sqlite3_column_type, returning the type of a column.
Note that this performs no bounds check against columnCount in Dart.
Implementation
SqlType columnType(int index) {
return rawStatement.sqlite3_column_type(index);
}
Calls sqlite3_column_type, returning the type of a column.
Note that this performs no bounds check against columnCount in Dart.
SqlType columnType(int index) {
return rawStatement.sqlite3_column_type(index);
}