compileOptions property
An iterable over the list of options that were defined at compile time.
Implementation
Iterable<String> get compileOptions;
An iterable over the list of options that were defined at compile time.
Iterable<String> get compileOptions;