usedCompileOption abstract method
Whether the option, specified by its name, was defined at compile-time.
The SQLITE_ prefix may be omitted from the option name.
Implementation
bool usedCompileOption(String name);
Whether the option, specified by its name, was defined at compile-time.
The SQLITE_ prefix may be omitted from the option name.
bool usedCompileOption(String name);