xOpen abstract method
Opens a file, returning supported flags and a file instance.
Implementation
XOpenResult xOpen(Sqlite3Filename path, int flags);
Opens a file, returning supported flags and a file instance.
XOpenResult xOpen(Sqlite3Filename path, int flags);