xSectorSize property
int
get
xSectorSize
The sector size of the device that underlies the file.
The sector size is the minimum write that can be performed without disturbing other bytes in the file.
Implementation
int get xSectorSize;