HttpFinchResponse class
Constructors
-
HttpFinchResponse(HttpClientResponse _httpClientResponse, {required List<
int> bodyBytes})
Properties
- body → String
-
no setter
-
bodyBytes
→ List<
int> -
final
- error → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → HttpHeaders
-
no setter
- jsonBody → dynamic
-
no setter
- reasonPhrase → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
no setter
- success → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited