ErrorWidget class

A widget that provides an HTML layout for displaying error messages. The ErrorWidget class implements FinchStringWidget and provides a predefined HTML structure to be used for rendering error messages in the application. It includes styles and structure for displaying error details and stack traces.

Implemented types

Constructors

ErrorWidget()

Properties

generateHtml Tag Function(Map args)?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
layout String
The default HTML layout used by this widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited