The default HTML layout used by this widget.
This layout is represented as a string and is intended to be extended or overridden by subclasses to provide custom HTML content.
@override final String layout = '';