removeCommandBar static method
void
removeCommandBar()
Clears the current command bar text and redraws the prompt.
Implementation
static void removeCommandBar() {
if (_activeBuffer == null) return;
var len = _activeBuffer!.length;
// Move cursor back, overwrite with spaces, move back again
stdout.write('\r${_activePromptLabel}${' ' * len}\r${_activePromptLabel}');
_activeBuffer!.clear();
}