console library

Classes

Console
A utility class for logging messages with different severity levels. The Console class provides static methods for logging warnings, errors, information, debugging messages, and fatal errors. The logs are managed using the Logger package and optionally printed to the console. Example usage:
LanguageToDart
Log
Print
WidgetToDart

Enums

LogLevel

Functions

main(List<String> args) → void

Typedefs

LogCallback = void Function(Object? log, String type)