CronSchedule class
Internal parsed cron schedule supporting the 5-field (min hour day month weekday)
and 6-field (sec min hour day month weekday) formats.
Supports *, single values, comma-separated lists, - ranges and */n or
a-b/n step values, matching the syntax used throughout FinchCron's helpers
(e.g. evrySecond, evryMinute).
Constructors
Properties
-
days
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hours
→ List<
int> ? -
final
-
minutes
→ List<
int> ? -
final
-
months
→ List<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seconds
→ List<
int> ? -
final
-
weekdays
→ List<
int> ? -
final
Methods
-
matches(
DateTime time) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited