Annotations class
Optional client hints attached to MCP content objects.
Constructors
-
Annotations({int? priority, String? lastModified, List<
Role> ? audience}) -
Annotations.toMCP(Map<
String, Object?> map) -
factory
Properties
-
audience
↔ List<
Role> ? -
Intended audience roles for this content.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified ↔ String?
-
ISO 8601 timestamp of last modification.
getter/setter pair
- priority ↔ int?
-
Importance from
0(least) to1(most important).getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited