CallToolRequestParams class
Parameters for a tools/call request.
Constructors
-
CallToolRequestParams({TaskMetadata? task, RequestMetaObject? $meta, dynamic inputResponses, String? requestState, required String name, Map<
String, Object?> ? arguments}) -
CallToolRequestParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ RequestMetaObject?
-
Optional request metadata.
getter/setter pair
-
arguments
↔ Map<
String, Object?> ? -
Tool call arguments.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputResponses ↔ dynamic
-
Optional input responses (for multi-turn flows).
getter/setter pair
- name ↔ String
-
Name of the tool to invoke.
getter/setter pair
- requestState ↔ String?
-
Optional request state token.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task ↔ TaskMetadata?
-
Optional task-augmentation metadata.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited