CallToolRequestParams class

Parameters for a tools/call request.

Inheritance

Constructors

CallToolRequestParams({required RequestMetaObject $meta, InputResponses inputResponses, String? requestState, required String name, Map<String, Object?>? arguments})
CallToolRequestParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta RequestMetaObject
Request metadata (required — carries protocol version & capabilities).
getter/setter pairinherited
arguments Map<String, Object?>?
Tool call arguments.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputResponses InputRequests
Responses to a prior InputRequiredResult.inputRequests.
getter/setter pairinherited
name String
Name of the tool to invoke.
getter/setter pair
requestState String?
Opaque state token echoed back from a prior InputRequiredResult.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited