CancelledNotification class
Sent by the client to indicate it is cancelling a previously-issued request.
On stdio, the server also sends this notification, solely to terminate a
SubscriptionsListenRequest stream: it references the ID of the
subscriptions/listen request that opened the stream. Servers MUST NOT
use this notification to cancel any other request.
Constructors
- CancelledNotification({required CancelledNotificationParams params})
-
CancelledNotification.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonrpc ↔ String
-
getter/setter pair
- method ↔ String
-
getter/setter pair
- params ↔ CancelledNotificationParams
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited