CompleteRequestParams class

Inheritance

Constructors

CompleteRequestParams({required RequestMetaObject $meta, required Reference ref, required CompleteRequestParamsArgument argument, CompleteRequestParamsContext? context})
CompleteRequestParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta RequestMetaObject
getter/setter pair
argument CompleteRequestParamsArgument
getter/setter pair
context CompleteRequestParamsContext?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ref Reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited