CreateMessageRequestParams class

Inheritance

Constructors

CreateMessageRequestParams({required List<SamplingMessage> messages, ModelPreferences? modelPreferences, String? systemPrompt, String? includeContext, num? temperature, required int maxTokens, List<String>? stopSequences, Map<String, Object?>? metadata, List<Tool>? tools, ToolChoice? toolChoice})
CreateMessageRequestParams.toMCP(Map<String, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
includeContext String?
getter/setter pair
maxTokens int
getter/setter pair
messages List<SamplingMessage>
getter/setter pair
metadata Map<String, Object?>?
getter/setter pair
modelPreferences ModelPreferences?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopSequences List<String>?
getter/setter pair
systemPrompt String?
getter/setter pair
temperature num?
getter/setter pair
toolChoice ToolChoice?
getter/setter pair
tools List<Tool>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited