CreateMessageResult class
Constructors
-
CreateMessageResult({required String model, String? stopReason, required Role role, required List<
ContentBlock> content, MetaObject? $meta}) -
CreateMessageResult.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
getter/setter pair
-
content
↔ List<
ContentBlock> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- model ↔ String
-
getter/setter pair
- role ↔ Role
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopReason ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited