DiscoverRequest class
Requests the server's capability advertisement out-of-band, replacing
the former initialize handshake now that protocol negotiation happens
per-request via RequestMetaObject.
Constructors
- DiscoverRequest({required String id, required RequestParams params})
-
DiscoverRequest.toMCP(Map<
String, Object?> map) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited