ElicitRequestFormParams class
The parameters for a request to elicit non-sensitive information from the user via a form in the client.
- Inheritance
-
- Object
- MCP
- ElicitRequestParams
- ElicitRequestFormParams
Constructors
- ElicitRequestFormParams({required String message, ElicitRequestFormParamsSchema? requestedSchema})
- Creates an ElicitRequestFormParams.
-
ElicitRequestFormParams.toMCP(Map<
String, Object?> map) -
Builds an ElicitRequestFormParams from a decoded MCP JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
The message to present to the user describing what information is being requested.
getter/setter pair
- mode ↔ String
-
Discriminator — always
"form"(the default).getter/setter pair - requestedSchema ↔ ElicitRequestFormParamsSchema?
-
A restricted subset of JSON Schema.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this ElicitRequestFormParams into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited