ElicitRequestFormParams class

Inheritance

Constructors

ElicitRequestFormParams({TaskMetadata? task, RequestMetaObject? $meta, required String message, ElicitRequestFormParamsSchema? requestedSchema})
ElicitRequestFormParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta RequestMetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
jsonrpc String
getter/setter pairinherited
message String
getter/setter pair
node String
getter/setter pair
requestedSchema ElicitRequestFormParamsSchema?
getter/setter pair
result ElicitResult
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task TaskMetadata?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited