ElicitRequestFormParams class
- Inheritance
-
- Object
- MCP
- ElicitRequestParams
- ElicitRequestFormParams
Constructors
- ElicitRequestFormParams({required String message, ElicitRequestFormParamsSchema? requestedSchema})
-
ElicitRequestFormParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
getter/setter pair
- mode ↔ String
-
Discriminator — always
"form"(the default).getter/setter pair - requestedSchema ↔ ElicitRequestFormParamsSchema?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited