Icon class
An optionally-sized icon that may be displayed in a UI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String?
-
Optional MIME-type override.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sizes
↔ List<
String> ? -
Sizes at which the icon can be used, e.g.
["48x48", "any"].getter/setter pair - src ↔ String
-
URI pointing to the icon resource (HTTP/HTTPS or
data:URI).getter/setter pair - theme ↔ Theme?
-
Theme the icon is designed for.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited