Implementation class
Describes an MCP client or server implementation.
Constructors
Properties
- description ↔ String?
-
Optional human-readable description.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
icons
↔ List<
Icon> ? -
Optional display icons.
getter/setter pair
- name ↔ String
-
Programmatic name.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Optional human-readable display title.
getter/setter pair
- version ↔ String?
-
Implementation version string.
getter/setter pair
- websiteUrl ↔ String?
-
Optional website URL.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited