JSONRPCNotification class
A JSON-RPC 2.0 notification (a request with no expected response).
- Inheritance
-
- Object
- MCP
- JSONRPCMessage
- JSONRPCNotification
Constructors
-
JSONRPCNotification({String jsonrpc = '2.0', required String method, Map<
String, Object?> ? params}) -
JSONRPCNotification.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonrpc ↔ String
-
JSON-RPC version string.
getter/setter pair
- method ↔ String
-
The notification method name.
getter/setter pair
-
params
↔ Map<
String, Object?> ? -
Optional notification parameters.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited