LoggingMessageNotificationParams class
Parameters for a logging/message notification.
Constructors
- LoggingMessageNotificationParams({MetaObject? $meta, required LoggingLevel level, String? logger, required dynamic data})
-
LoggingMessageNotificationParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
Optional metadata.
getter/setter pair
- data ↔ dynamic
-
Arbitrary log data (string or JSON-serialisable object).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ LoggingLevel
-
Severity level.
getter/setter pair
- logger ↔ String?
-
Optional name of the issuing logger.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited