NumberSchema class

Inheritance

Constructors

NumberSchema({String type = 'number', num? minimum, num? maximum, num? defaultValue, String? title, String? description})
NumberSchema.toMCP(Map<String, Object?> map)
factory

Properties

defaultValue num?
getter/setter pairinherited
description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
maximum num?
getter/setter pair
minimum num?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pairinherited
type String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited