ProgressNotificationParams class
Constructors
- ProgressNotificationParams({MetaObject? $meta, required String progressToken, required num progress, num? total, String? message})
-
ProgressNotificationParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
_meta?: MetaObject;
progressToken: ProgressToken;
progress: number;
total?: number;
message?: string;
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- progress ↔ num
-
getter/setter pair
- progressToken ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total ↔ num?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited