progressToken property
The progress token which was given in the initial request, used to associate this notification with the request that is proceeding.
Implementation
String progressToken;
The progress token which was given in the initial request, used to associate this notification with the request that is proceeding.
String progressToken;