PromptArgument class
Describes an argument accepted by a Prompt.
Constructors
- PromptArgument({required String name, String? title, String? description, bool? required})
-
PromptArgument.toMCP(Map<
String, Object?> map) -
factory
Properties
- description ↔ String?
-
Optional description of the argument.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
Programmatic argument name.
getter/setter pair
- required ↔ bool?
-
Whether the argument must be provided.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Human-readable display title.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited