logLevel property
- @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')
The desired log level for this request.
Implementation
@Deprecated(
'Deprecated as of protocol version 2026-07-28 (SEP-2577). '
'Remains in the specification for at least twelve months.',
)
LoggingLevel? get logLevel =>
data['io.modelcontextprotocol/logLevel'] != null
? LoggingLevel.to(data['io.modelcontextprotocol/logLevel'] as String)
: null;
- @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')
Implementation
@Deprecated(
'Deprecated as of protocol version 2026-07-28 (SEP-2577). '
'Remains in the specification for at least twelve months.',
)
set logLevel(LoggingLevel? value) =>
data['io.modelcontextprotocol/logLevel'] = value?.toString();