ResourceUpdatedNotification class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonrpc String
jsonrpc: “2.0”; method: “notifications/resources/updated”; params: ResourceUpdatedNotificationParams;
getter/setter pair
method String
getter/setter pair
params ResourceUpdatedNotificationParams
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited