ResourceUpdatedNotificationParams class

Inheritance
  • Object
  • MCP
  • ResourceUpdatedNotificationParams

Constructors

ResourceUpdatedNotificationParams({MetaObject? $meta, required String resourceId, String? resourceType, Map<String, Object?>? data})
ResourceUpdatedNotificationParams.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
jsonrpc: “2.0”; method: “notifications/resources/updated”; params: ResourceUpdatedNotificationParams;
getter/setter pair
data Map<String, Object?>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resourceId String
getter/setter pair
resourceType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited