Result class
Generic MCP result that may carry arbitrary extra fields.
- Inheritance
- Implemented types
Constructors
-
Result({MetaObject? meta, Map<
String, Object?> ? unknown}) -
Result.toMCP(Map<
String, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta ↔ MetaObject?
-
Optional
_metaobject.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unknown
↔ Map<
String, Object?> ? -
Any additional unknown fields returned by the server.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited