SamplingMessage class

Inheritance
Annotations
  • @Deprecated('Deprecated as of protocol version 2026-07-28 (SEP-2577). ' 'Remains in the specification for at least twelve months.')

Constructors

SamplingMessage({required Role role, required List<SamplingMessageContentBlock> content, MetaObject? $meta})
SamplingMessage.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
getter/setter pair
content List<SamplingMessageContentBlock>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
role Role
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited