SubscriptionFilter class

Filter describing which change notifications a subscriptions/listen stream should deliver.

Inheritance

Constructors

SubscriptionFilter({bool? toolsListChanged, bool? promptsListChanged, bool? resourcesListChanged, List<String>? resourceSubscriptions})
SubscriptionFilter.toMCP(Map<String, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
promptsListChanged bool?
getter/setter pair
resourcesListChanged bool?
getter/setter pair
resourceSubscriptions List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsListChanged bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited