SubscriptionsAcknowledgedNotificationParams class
The first message a server sends after a client opens a new
subscriptions/listen stream, acknowledging which notifications it will
deliver on it.
Constructors
- SubscriptionsAcknowledgedNotificationParams({NotificationMetaObject? $meta, required SubscriptionFilter notifications})
-
SubscriptionsAcknowledgedNotificationParams.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ NotificationMetaObject?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifications ↔ SubscriptionFilter
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited