Task class
Data associated with an MCP task.
- Inheritance
- Implemented types
Constructors
Properties
- createdAt ↔ String
-
ISO 8601 creation timestamp.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUpdatedAt ↔ String
-
ISO 8601 last-updated timestamp.
getter/setter pair
- pollInterval ↔ int?
-
Suggested polling interval in ms.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ TaskStatus
-
Current task state.
getter/setter pair
- statusMessage ↔ String?
-
Optional human-readable status description.
getter/setter pair
- taskId ↔ String
-
Unique task identifier.
getter/setter pair
- ttl ↔ int?
-
Retention duration in ms from creation;
null= unlimited.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited