TextContent class
Plain-text content for LLM interactions.
- Inheritance
-
- Object
- MCP
- ContentBlock
- TextContent
Constructors
- TextContent({required String text, required String mimeType, Annotations? annotations, MetaObject? $meta})
-
TextContent.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
Optional metadata.
getter/setter pairinherited
- annotations ↔ Annotations?
-
Optional client annotations.
getter/setter pairinherited
- data ↔ String
-
Base64-encoded binary data (used for image / audio content).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String
-
MIME type of data.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
The text payload.
getter/setter pair
- type ↔ String
-
The content type discriminator (e.g.
"text","image","audio").getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited