ToolAnnotations class
Behavioural hints for a Tool (all properties are advisory).
Constructors
- ToolAnnotations({String? title, bool? readOnlyHint, bool? destructiveHint, bool? idempotentHint, bool? openWorldHint})
-
ToolAnnotations.toMCP(Map<
String, Object?> map) -
factory
Properties
- destructiveHint ↔ bool?
-
If
true, the tool may perform destructive updates.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- idempotentHint ↔ bool?
-
If
true, repeated calls with identical arguments have no extra effect.getter/setter pair - openWorldHint ↔ bool?
-
If
true, the tool interacts with an open world of external entities.getter/setter pair - readOnlyHint ↔ bool?
-
If
true, the tool does not modify its environment.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Human-readable title.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited