ToolResultContent class
- Inheritance
-
- Object
- MCP
- ContentBlock
- ToolResultContent
Constructors
-
ToolResultContent({required String toolUseId, required List<
ContentBlock> content, Map<String, Object?> ? structuredContent, bool? isError, Annotations? annotations, MetaObject? $meta}) -
ToolResultContent.toMCP(Map<
String, Object?> map) -
factory
Properties
- $meta ↔ MetaObject?
-
Optional metadata.
getter/setter pairinherited
- annotations ↔ Annotations?
-
Optional client annotations.
getter/setter pairinherited
-
content
↔ List<
ContentBlock> -
getter/setter pair
- data ↔ String
-
Base64-encoded binary data (used for image / audio content).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError ↔ bool?
-
getter/setter pair
- mimeType ↔ String
-
MIME type of data.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
structuredContent
↔ Map<
String, Object?> ? -
getter/setter pair
- toolUseId ↔ String
-
getter/setter pair
- type ↔ String
-
The content type discriminator (e.g.
"text","image","audio").getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited