ToolSchema class
JSON Schema object used for a tool's inputSchema or outputSchema.
Constructors
Properties
- $schema ↔ String?
-
Optional
$schemaURI.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
↔ Map<
String, Object?> ? -
Property definitions.
getter/setter pair
-
required
↔ List<
String> ? -
Required property names.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
Root type; always
"object".getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited