ToolUseContent class

Inheritance

Constructors

ToolUseContent({required String id, required String name, required Map<String, Object?> input, Annotations? annotations, MetaObject? $meta})
ToolUseContent.toMCP(Map<String, Object?> map)
factory

Properties

$meta MetaObject?
Optional metadata.
getter/setter pairinherited
annotations Annotations?
Optional client annotations.
getter/setter pairinherited
data String
Base64-encoded binary data (used for image / audio content).
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
input Map<String, Object?>
getter/setter pair
mimeType String
MIME type of data.
getter/setter pairinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The content type discriminator (e.g. "text", "image", "audio").
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited