UntitledSingleSelectEnumSchema class
- Inheritance
-
- Object
- MCP
- Schema<
String> - PrimitiveSchemaDefinition<
String> - EnumSchema<
String> - SingleSelectEnumSchema<
String> - UntitledSingleSelectEnumSchema
Constructors
-
UntitledSingleSelectEnumSchema({required List<
String> $enum, String? defaultValue, String? title, String? description}) -
UntitledSingleSelectEnumSchema.toMCP(Map<
String, Object?> map) -
factory
Properties
-
$enum
↔ List<
String> -
getter/setter pair
- defaultValue ↔ String?
-
getter/setter pairinherited
- description ↔ String?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
getter/setter pairinherited
- type ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited