DartMigration class abstract
Constructors
- DartMigration(String uniqueName)
Properties
- app ↔ FinchApp
-
getter/setter pair
-
downSQLs
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target ↔ MigrationTarget
-
getter/setter pair
- uniqueName → String
-
final
-
upSQLs
→ List<
String> -
no setter
Methods
-
addSql(
String sql) → DartMigration -
down(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
FinchApp app) → DartMigration -
toString(
) → String -
A string representation of this object.
override
-
up(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited