leak abstract method
Like handle, this returns the native sqlite3_stmt* pointer wrapped by
this instance.
Additionally, this also detaches native finalizers that would close the statement once this object becomes unreachable.
This is an advanced and low-level API that can be used to transfer ownership of statements originally opened in Dart to native code.
Implementation
Pointer<void> leak();