fromPointer abstract method
Creates a Database from an opened sqlite3 database connection.
The database must be a pointer towards an open sqlite3 database
connection handle.
When borrowed is set (it defaults to false), the returned Database
connection acts as a view of the underlying sqlite3* pointer. The
library will not attach a native finalizer calling sqlite3_close_v2, and
calling Database.close in it will only prevent further interactions from
Dart.
Implementation
Database fromPointer(Pointer<void> database, {bool borrowed = false});