sqliteCloseV2 property
- @Deprecated("Import 'package:sqlite3/unstable/ffi_bindings.dart' instead")
A function pointer to sqlite3_close_v2.
This typically shouldn't be used directly since this library attaches native finalizers to databases by default, but can be used for custom connection management if necessary.
See also: https://sqlite.org/c3ref/close.html
Implementation
@Deprecated("Import 'package:sqlite3/unstable/ffi_bindings.dart' instead")
static Pointer<NativeFunction<Int Function(Pointer<Void>)>>
get sqliteCloseV2 => libsqlite3.addresses.sqlite3_close_v2.cast();